@@ -1,6 +1,6 @@
 package Bundle::BioPerl;
 
-$VERSION = '2.04';
+$VERSION = '2.05';
 
 1;
 
@@ -58,6 +58,10 @@ XML::Node		- recommended for all bioperl releases after 0.6.2
 
 XML::Twig		- recommended for all bioperl releases after 0.6.2
 
+Text::Iconv		- dependency for XML::Twig
+
+Scalar::Util		- dependency for XML::Twig
+
 XML::DOM		- used only by SeqIO::bsml
 
 SOAP::Lite		- Used for bibliographic queries & XEMBLService modules
@@ -68,6 +72,12 @@ Storable		- recommended for all bioperl releases after 0.7.2. Used for persistan
 
 Text::Shellwords		- Text parser used by Bio::Graphics::FeatureFile.pm
 
+Data::Stag		- This module is used by our SeqIO/chado* modules.  
+
+Graph::Directed		- This module is used for Ontology Engine implementation for the GO parser
+  
+
+
 =head1 DESCRIPTION
 
 The BioPerl distribution from http://bioperl.org contains code and
@@ -77,9 +87,9 @@ contained within the standard Perl distribution. These external
 modules can be obtained from the Comprehensive Perl Archive 
 Network (CPAN) located at http://www.cpan.org. 
 
-December 2002 NOTE: The latest release of this bundle includes all of the
+NOTE: The latest release of this bundle includes all of the
 external CPAN modules that are listed as dependencies of the
-official BioPerl 1.2 codebase release. The only exceptions are the DBD::
+official BioPerl 1.2.1 codebase release. The only exceptions are the DBD::
 DBI:: modules which are really best off installed on their own if you
 have a need to load and query relational databases.
 
